@@ -8,6 +8,7 @@
 #define KANDROIDEXTRAS_MANIFESTPERMISSIONM_H
 
 #include <KAndroidExtras/AndroidTypes>
+#include <KAndroidExtras/JniObject>
 #include <KAndroidExtras/JniProperty>
 #include <KAndroidExtras/JavaTypes>
 
@@ -19,9 +20,10 @@ namespace KAndroidExtras {
  */
 class ManifestPermission
 {
-    JNI_OBJECT(ManifestPermission, android::Manifest_permission)
+    JNI_UNMANAGED_OBJECT(ManifestPermission, android::Manifest_permission)
 public:
     JNI_CONSTANT(java::lang::String, READ_CALENDAR)
+    JNI_CONSTANT(java::lang::String, WRITE_CALENDAR)
     JNI_CONSTANT(java::lang::String, READ_EXTERNAL_STORAGE)
     JNI_CONSTANT(java::lang::String, WRITE_EXTERNAL_STORAGE)
 };
